@@ -31,6 +31,7 @@ from utilities.text import (
     parse_bool,
     parse_none,
     pascal_case,
+    prompt_bool,
     repr_encode,
     secret_str,
     snake_case,
@@ -166,6 +167,11 @@ class TestPascalAndSnakeCase:
         assert snake_case(text) == exp_snake
 
 
+class TestPromptBool:
+    def test_main(self) -> None:
+        assert prompt_bool(confirm=True)
+
+
 class TestSecretStr:
     def test_main(self) -> None:
         s = secret_str("text")
