@@ -126,7 +126,7 @@ class GetEnvVarError(Exception):
 
 def is_debug() -> bool:
     """Check if we are in `DEBUG` mode."""
-    return "DEBUG" in environ
+    return get_env_var("DEBUG", nullable=True) is not None
 
 
 ##
@@ -134,7 +134,7 @@ def is_debug() -> bool:
 
 def is_pytest() -> bool:
     """Check if `pytest` is running."""
-    return "PYTEST_VERSION" in environ
+    return get_env_var("PYTEST_VERSION", default=None) is not None
 
 
 ##
