@@ -6,7 +6,7 @@ from collections.abc import Set as AbstractSet
 from dataclasses import asdict, dataclass
 from functools import partial, reduce
 from itertools import chain, pairwise, product
-from math import ceil, log
+from math import ceil, log, pi, sqrt
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Literal, assert_never, cast, overload, override
 from uuid import UUID
@@ -56,12 +56,7 @@ from whenever import DateDelta, DateTimeDelta, PlainDateTime, TimeDelta, ZonedDa
 import utilities.math
 from utilities.dataclasses import yield_fields
 from utilities.errors import ImpossibleCaseError
-from utilities.functions import (
-    get_class_name,
-    is_dataclass_class,
-    is_dataclass_instance,
-    make_isinstance,
-)
+from utilities.functions import get_class_name
 from utilities.gzip import read_binary
 from utilities.iterables import (
     CheckIterablesEqualError,
@@ -91,11 +86,14 @@ from utilities.reprlib import get_repr
 from utilities.types import MaybeStr, Number, PathLike, WeekDay
 from utilities.typing import (
     get_args,
+    is_dataclass_class,
+    is_dataclass_instance,
     is_frozenset_type,
     is_list_type,
     is_literal_type,
     is_optional_type,
     is_set_type,
+    make_isinstance,
 )
 from utilities.warnings import suppress_warnings
 from utilities.whenever import (
@@ -1931,7 +1929,49 @@ def nan_sum_horizontal(*columns: IntoExprColumn) -> ExprOrSeries:
 ##
 
 
-def normal(
+@overload
+def normal_pdf(
+    x: ExprLike,
+    /,
+    *,
+    loc: float | IntoExprColumn = 0.0,
+    scale: float | IntoExprColumn = 1.0,
+) -> Expr: ...
+@overload
+def normal_pdf(
+    x: Series,
+    /,
+    *,
+    loc: float | IntoExprColumn = 0.0,
+    scale: float | IntoExprColumn = 1.0,
+) -> Series: ...
+@overload
+def normal_pdf(
+    x: IntoExprColumn,
+    /,
+    *,
+    loc: float | IntoExprColumn = 0.0,
+    scale: float | IntoExprColumn = 1.0,
+) -> ExprOrSeries: ...
+def normal_pdf(
+    x: IntoExprColumn,
+    /,
+    *,
+    loc: float | IntoExprColumn = 0.0,
+    scale: float | IntoExprColumn = 1.0,
+) -> ExprOrSeries:
+    """Compute the PDF of a normal distribution."""
+    x = ensure_expr_or_series(x)
+    loc = loc if isinstance(loc, int | float) else ensure_expr_or_series(loc)
+    scale = scale if isinstance(scale, int | float) else ensure_expr_or_series(scale)
+    expr = (1 / (scale * sqrt(2 * pi))) * (-(1 / 2) * ((x - loc) / scale) ** 2).exp()
+    return try_reify_expr(expr, x)
+
+
+##
+
+
+def normal_rv(
     obj: int | Series | DataFrame,
     /,
     *,
@@ -1950,11 +1990,11 @@ def normal(
             values = rng.normal(loc=loc, scale=scale, size=height)
             return Series(name=name, values=values, dtype=dtype)
         case Series() as series:
-            return normal(
+            return normal_rv(
                 series.len(), loc=loc, scale=scale, seed=seed, name=name, dtype=dtype
             )
         case DataFrame() as df:
-            return normal(
+            return normal_rv(
                 df.height, loc=loc, scale=scale, seed=seed, name=name, dtype=dtype
             )
         case never:
@@ -1966,22 +2006,22 @@ def normal(
 
 @overload
 def number_of_decimals(
-    series: ExprLike, /, *, max_decimals: int = MAX_DECIMALS
+    column: ExprLike, /, *, max_decimals: int = MAX_DECIMALS
 ) -> Expr: ...
 @overload
 def number_of_decimals(
-    series: Series, /, *, max_decimals: int = MAX_DECIMALS
+    column: Series, /, *, max_decimals: int = MAX_DECIMALS
 ) -> Series: ...
 @overload
 def number_of_decimals(
-    series: IntoExprColumn, /, *, max_decimals: int = MAX_DECIMALS
+    column: IntoExprColumn, /, *, max_decimals: int = MAX_DECIMALS
 ) -> ExprOrSeries: ...
 def number_of_decimals(
-    series: IntoExprColumn, /, *, max_decimals: int = MAX_DECIMALS
+    column: IntoExprColumn, /, *, max_decimals: int = MAX_DECIMALS
 ) -> ExprOrSeries:
     """Get the number of decimals."""
-    series = ensure_expr_or_series(series)
-    frac = series - series.floor()
+    column = ensure_expr_or_series(column)
+    frac = column - column.floor()
     results = (
         _number_of_decimals_check_scale(frac, s) for s in range(max_decimals + 1)
     )
@@ -2699,7 +2739,8 @@ __all__ = [
     "map_over_columns",
     "nan_sum_agg",
     "nan_sum_horizontal",
-    "normal",
+    "normal_pdf",
+    "normal_rv",
     "number_of_decimals",
     "offset_datetime",
     "one_column",
